#
# spec file for package ocaml-findlib
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2010-2011 Andrew Psaltis <ampsaltis at gmail dot com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define opt %(test -x %{_bindir}/ocamlopt && echo 1 || echo 0)
%if !%opt
# get rid of /usr/lib/rpm/find-debuginfo.sh
# strip kills the bytecode part of ELF binaries
# see also NO_BRP_STRIP_DEBUG in install section
%undefine _build_create_debug
%endif

Name:           ocaml-findlib
Version:        1.3.3
Release:        2.2
Summary:        Objective CAML package manager and build helper
License:        MIT
Group:          Development/Libraries/Other

Url:            http://projects.camlcity.org/projects/findlib.html
Source0:        findlib-%{version}.tar.xz
Patch0:         findlib-1.3.3.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Provides:       ocamlfind = %{version}
BuildRequires:	xz
BuildRequires:  gawk
BuildRequires:  m4
BuildRequires:  ncurses-devel
BuildRequires:  ocaml
BuildRequires:  ocaml-camlp4-devel
BuildRequires:  ocaml-ocamldoc

%description
Findlib is a library manager for Objective Caml. It provides a
convention how to store libraries, and a file format ("META") to
describe the properties of libraries. There is also a tool (ocamlfind)
for interpreting the META files, so that it is very easy to use
libraries in programs and scripts.


%package        devel
Summary:        Development files for ocaml-findlib
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}

%description    devel
The ocaml-findlib-devel package contains libraries and signature files
for developing applications that use ocaml-findlib.


%prep
%setup -q -n findlib-%{version}
%patch0 -p1

%build
(cd tools/extract_args && make)
tools/extract_args/extract_args -o src/findlib/ocaml_args.ml ocamlc ocamlcp ocamlmktop ocamlopt ocamldep ocamldoc ||:
#cat src/findlib/ocaml_args.ml
./configure -config %{_sysconfdir}/ocamlfind.conf \
  -bindir %{_bindir} \
  -sitelib `ocamlc -where` \
  -mandir %{_mandir} \
  -with-toolbox
make all
%if %opt
make opt
%endif
rm doc/guide-html/TIMESTAMP

%install
%if !%opt
# get rid of /usr/lib/rpm/brp-strip-debug 
# strip kills the bytecode part of ELF binaries
export NO_BRP_STRIP_DEBUG=true
%endif
make install DESTDIR=$RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
%doc LICENSE doc/README
%config(noreplace) %{_sysconfdir}/ocamlfind.conf
%{_bindir}/*
%{_mandir}/man?/*
%{_libdir}/ocaml/bigarray
%{_libdir}/ocaml/dbm
%{_libdir}/ocaml/dynlink
%{_libdir}/ocaml/graphics
%{_libdir}/ocaml/num
%{_libdir}/ocaml/stdlib
%{_libdir}/ocaml/str
%{_libdir}/ocaml/unix
%{_libdir}/ocaml/camlp4
%{_libdir}/ocaml/ocamlbuild
%{_libdir}/ocaml/threads
%{_libdir}/ocaml/topfind
%{_libdir}/ocaml/findlib
%{_libdir}/ocaml/compiler-libs
%if %opt
%exclude %{_libdir}/ocaml/findlib/*.a
%exclude %{_libdir}/ocaml/findlib/*.cmxa
%endif
%exclude %{_libdir}/ocaml/findlib/*.mli
%exclude %{_libdir}/ocaml/findlib/Makefile.config
%{_libdir}/ocaml/num-top

%files devel
%defattr(-,root,root,-)
%doc LICENSE doc/README doc/guide-html
%if %opt
%{_libdir}/ocaml/findlib/*.a
%{_libdir}/ocaml/findlib/*.cmxa
%endif
%{_libdir}/ocaml/findlib/*.mli
%{_libdir}/ocaml/findlib/Makefile.config

%changelog
* Mon Jun  3 2013 ohering@suse.de
- Recompress with xz
* Fri Mar  8 2013 ohering@suse.de
- remove ExclusiveArch, its a generic package which depends on ocaml
* Thu Feb 21 2013 ohering@suse.de
- package compiler-libs/
* Wed Jan 16 2013 ohering@suse.de
- disable also /usr/lib/rpm/find-debuginfo.sh
* Mon Jan 14 2013 ohering@suse.de
- disable strip, it destroys bytecode binaries
* Mon Jan 14 2013 ohering@suse.de
- change Requires: version-release to just Requires: version
* Fri Nov 23 2012 ohering@suse.de
- restore BuildRequire ocaml-camlp4-devel because the solver
  triggers only on package names
* Tue Nov 13 2012 ohering@suse.de
- add DESTDIR support
* Tue Sep 18 2012 ohering@suse.de
- BuildRequire just camlp4 to allow build within sles11 [fate#312159]
* Sun Sep 16 2012 ohering@suse.de
-  Update to upstream version 1.3.3
-  1.3.3: OCaml-4: using the new #remove_directory directive  if present.
  Better compatibility with the OCaml version from Homebrew.
-  1.3.2: Handling of empty arguments (Wojciech Meyer).
  Added entry for camlp4.fulllib.
  New switch -add for "ocamlfind install" (Hans Ole Rafaelsen).
  Further fixes for ocaml-4.00.
  Fixing the recognition of double .cmi interface files.
  Fixing -dontlink (it is now deeply interpreted).
-  1.3.1: Fixing a bug with ocamlmklib that slipped through in 1.3.0
-  1.3.0: Fixes for ocaml-4.00 (especially topfind).
  Emitting an error if the configuration file does not exist.
  Emitting a warning if the selected toolchain does not exist.
  camlp4 is referenced by "+camlp4" in META.
  Including the sources for the documentation in the tarball.
  License change (simplification) for num_top_printers.mli.
  Fix ocamlmklib wrapper: processing contracted args (like -L/dir) correctly.
  Many wrappers get a new option -passrest instructing to pass all remaining
  options on the command-line unchanged to the invoked tool.
  Prettified -help output.
-  1.2.8: Adding support for ocamlmklib (B. Meurer's patches)
  Fix for win32 in the configure script.
* Thu Sep 15 2011 ampsaltis@gmail.com
- Remove some unneeded commands in the build section
* Fri Jul 22 2011 ampsaltis@gmail.com
- Fix license (sort of, they're the same thing, really)
- Primary package provides ocamlfind
- Fixed some rpmlint warnings
* Fri Jun 17 2011 ampsaltis@gmail.com
- Use ocaml-camlp4-devel in BuildRequires
* Wed May 18 2011 ampsaltis@gmail.com
- Add this file.
- New upstream version 1.2.7
- Fix: if a META file defines several packages, and one of the packages
  has a broken dependency, ocamlfind used to report all errors even if
  the broken packages were not used. This is now changed - broken
  subpackages are ignored when they are not needed, in the same way as
  broken top-level packages are ignored when not needed. (Thanks to
  Sylvain Le Gall for reporting the problem.)
- Added -thread and -vmthread switches to "ocamlfind ocamldoc".
  These actually only add the right predicates. (Thanks to Vladimir
  Ivanov for pointing this problem out.)
- Package warnings can be emitted by "ocamlfind ocamldoc".
* Wed Apr 20 2011 ampsaltis@gmail.com
- Use internal dependency generator
